from ezgpx import GPX

# Parse GPX file
gpx = GPX("file.gpx")

# Remove metadata
gpx.remove_metadata()

# Remove elevation data
gpx.remove_elevation()

# Remove time data
gpx.remove_time()

# Write new simplified GPX file
gpx.to_gpx("new_file.gpx")


import ezgpx

# Check GPX schema when parsing file
gpx = ezgpx.GPX("file.gpx", check_xml_schemas=True, extensions_schemas=False)

# Check GPX schema and extensions schemas from GPX instance
gpx.check_xml_schemas(extensions_schemas=True)

# Check if written file follow GPX schema
gpx.to_gpx("new_file.gpx", check_xml_schemas=True, extensions_schemas=False)


from typing import List

from .extensions import *
from .link import Link
from .track_segment import *

class Track():
    """
    trkType element in GPX file.
    """

    def __init__(
            self,
            tag: str = "trk",
            name: str = None,
            cmt: str = None,
            desc: str = None,
            src: str = None,
            link: Link = None,
            number: int = None,
            type: str = None,
            extensions: Extensions = None,
            trkseg: List[TrackSegment] = None):
        """
        Initialize Track instance.

        Parameters
        ----------
        tag : str, optional
            XML tag, by default "trk"
        name : str, optional
            Name, by default None
        cmt : str, optional
            Comment, by default None
        desc : str, optional
            Description, by default None
        src : str, optional
            Source, by default None
        link : Link, optional
            Link, by default None
        number : int, optional
            Number, by default None
        type : str, optional
            Type, by default None
        extensions : Extensions, optional
            Extensions, by default None
        trkseg : List[TrackSegment], optional
            List of track segments, by default None
        """
        self.tag: str = tag
        self.name: str = name
        self.cmt: str = cmt
        self.desc: str = desc
        self.src: str = src
        self.link: Link = link
        self.number: int = number
        self.type: str = type
        self.extensions: Extensions = extensions
        self.trkseg: List[TrackSegment] = [] if trkseg is None else trkseg

    def project(self, projection: str):
        """
        Project segments.

        Parameters
        ----------
        projection : str
            Projection.
        """
        for segment in self.trkseg:
            segment.project(projection)


from .fit_parser import *
from .gpx import *
from .gpx_elements import *
from .gpx_parser import *
from .gpx_writer import *
from .kml_parser import *
from .kml_writer import *
from .parser import *
from .utils import *
from .writer import *
from .xml_parser import *



import ezgpx

# Parse GPX file
gpx = ezgpx.GPX("file.gpx")

# Save as GPX file
gpx.to_gpx("new_file.gpx")

# Save as KML file
gpx.to_kml("new_file.kml")

# Save as CSV file
gpx.to_csv("new_file.csv", columns=["lat", "lon", "ele"])

# Convert to Pandas Dataframe
df = gpx.to_dataframe()


import ezgpx

# Parse GPX file
gpx = ezgpx.GPX("file.gpx")

# Plot with Matplotlib
gpx.matplotlib_plot(color="elevation",
                    start_stop_colors=("green", "red"),
                    way_points_color="blue",
                    title=gpx.name(),
                    duration=(0, 0),
                    distance=(0.5, 0),
                    ascent=None,
                    pace=(1, 0),
                    speed=None,
                    file_path="img_1")

# Plot with Matplotlib Basemap Toolkit
gpx.matplotlib_basemap_plot(color="darkorange",
                            start_stop_colors=("darkgreen", "darkred"),
                            way_points_color="darkblue",
                            title=gpx.name(),
                            duration=(0,0),
                            distance=(0.5,0),
                            ascent=None,
                            pace=None,
                            speed=(1,0),
                            file_path="img_2")

# Plot with gmplot (Google Maps)
gpx.gmplot_plot(color="yellow",
                start_stop_colors=("green", "red"),
                way_points_color="blue",
                zoom=14,
                title=gpx.name(),
                file_path="map_1.html",
                open=False)

# Plot with Folium
gpx.folium_plot(tiles="OpenStreetMap",
                color="orange",
                start_stop_colors=("green", "red"),
                way_points_color="blue",
                minimap=True,
                coord_popup=False,
                title="Very nice track!",
                zoom=8,
                file_path="map_2.html",
                open=True)

# Write new GPX file
gpx.to_gpx("new_file.gpx")
